searchData={"items":[{"type":"module","doc":"Defines the core data structures for Session Types.\n\nSession Types (ST) provide a formal way to describe communication protocols\nbetween different roles in a distributed system. This module defines the\ndata structures that represent these session types after parsing.\n\nThe main session type constructs are:\n- `SIn` - For receiving messages (external choice)\n- `SOut` - For sending messages (internal choice)\n- `SEnd` - For terminating a session\n\nEach of these has convenience constructor functions available in this module.","title":"ST","ref":"ST.html"},{"type":"function","doc":"Creates a branch in a session type.","title":"ST.branch/3","ref":"ST.html#branch/3"},{"type":"function","doc":"- `label`: The message label (atom)\n- `payload`: The payload type\n- `continue_as`: The continuation session type","title":"Parameters - ST.branch/3","ref":"ST.html#branch/3-parameters"},{"type":"function","doc":"iex> ST.branch(:request, :binary, %ST.SEnd{})\n    %ST.SBranch{\n      label: :request,\n      payload: :binary,\n      continue_as: %ST.SEnd{}\n    }","title":"Example - ST.branch/3","ref":"ST.html#branch/3-example"},{"type":"function","doc":"Creates an end session type.","title":"ST.end_session/0","ref":"ST.html#end_session/0"},{"type":"function","doc":"iex> ST.end_session()\n    %ST.SEnd{}","title":"Example - ST.end_session/0","ref":"ST.html#end_session/0-example"},{"type":"function","doc":"Creates an input session type (for receiving messages).","title":"ST.input/2","ref":"ST.html#input/2"},{"type":"function","doc":"- `from`: The role sending the message(s)\n- `branches`: List of possible branches that can be received","title":"Parameters - ST.input/2","ref":"ST.html#input/2-parameters"},{"type":"function","doc":"iex> branch = ST.branch(:ack, :unit, %ST.SEnd{})\n    iex> ST.input(:server, [branch])\n    %ST.SIn{\n      from: :server,\n      branches: [%ST.SBranch{\n        label: :ack,\n        payload: :unit,\n        continue_as: %ST.SEnd{}\n      }]\n    }","title":"Example - ST.input/2","ref":"ST.html#input/2-example"},{"type":"function","doc":"Convenience function to create an input with a single branch.","title":"ST.input_one/4","ref":"ST.html#input_one/4"},{"type":"function","doc":"- `from`: The role sending the message\n- `label`: The message label\n- `payload`: The payload type\n- `continue_as`: The continuation session type","title":"Parameters - ST.input_one/4","ref":"ST.html#input_one/4-parameters"},{"type":"function","doc":"iex> ST.input_one(:server, :ack, :unit, %ST.SEnd{})\n    %ST.SIn{\n      from: :server,\n      branches: [%ST.SBranch{\n        label: :ack,\n        payload: :unit,\n        continue_as: %ST.SEnd{}\n      }]\n    }","title":"Example - ST.input_one/4","ref":"ST.html#input_one/4-example"},{"type":"function","doc":"Creates an output session type (for sending messages).","title":"ST.output/2","ref":"ST.html#output/2"},{"type":"function","doc":"- `to`: The role receiving the message(s)\n- `branches`: List of possible branches that can be sent","title":"Parameters - ST.output/2","ref":"ST.html#output/2-parameters"},{"type":"function","doc":"iex> branch = ST.branch(:request, :binary, %ST.SEnd{})\n    iex> ST.output(:client, [branch])\n    %ST.SOut{\n      to: :client,\n      branches: [%ST.SBranch{\n        label: :request,\n        payload: :binary,\n        continue_as: %ST.SEnd{}\n      }]\n    }","title":"Example - ST.output/2","ref":"ST.html#output/2-example"},{"type":"function","doc":"Convenience function to create an output with a single branch.","title":"ST.output_one/4","ref":"ST.html#output_one/4"},{"type":"function","doc":"- `to`: The role receiving the message\n- `label`: The message label\n- `payload`: The payload type\n- `continue_as`: The continuation session type","title":"Parameters - ST.output_one/4","ref":"ST.html#output_one/4-parameters"},{"type":"function","doc":"iex> ST.output_one(:client, :request, :binary, %ST.SEnd{})\n    %ST.SOut{\n      to: :client,\n      branches: [%ST.SBranch{\n        label: :request,\n        payload: :binary,\n        continue_as: %ST.SEnd{}\n      }]\n    }","title":"Example - ST.output_one/4","ref":"ST.html#output_one/4-example"},{"type":"type","doc":"A payload type that can be:\n- A basic type (:binary, :number, :boolean, :unit)\n- A list of a basic type\n- A tuple containing multiple payload types","title":"ST.payload_type/0","ref":"ST.html#t:payload_type/0"},{"type":"type","doc":"A session type that can be:\n- An input type (receiving messages)\n- An output type (sending messages)\n- A termination marker","title":"ST.t/0","ref":"ST.html#t:t/0"},{"type":"module","doc":"User-friendly API for the Session Type Parser.\n\nThis module provides convenient functions for parsing session type expressions\ninto their corresponding ST data structures. It serves as the main entry point\nfor using the parser in application code.","title":"ST.Parser","ref":"ST.Parser.html"},{"type":"module","doc":"The syntax supported by this parser includes:\n\n- Input (external choice): `&Role:{ Label1(PayloadType).Continuation, Label2(PayloadType).Continuation }`\n- Output (internal choice): `+Role:{ Label1(PayloadType).Continuation, Label2(PayloadType).Continuation }`\n- End (termination): `end`","title":"Session Type Syntax - ST.Parser","ref":"ST.Parser.html#module-session-type-syntax"},{"type":"module","doc":"The following payload types are supported:\n- Basic types: `string`, `number`, `boolean`, `unit`\n- List types: `type[]` (e.g., `string[]`, `number[]`)\n- Tuple types: `(type1, type2, ...)` (e.g., `(string, number)`, `(boolean[], unit)`)","title":"Payload Types - ST.Parser","ref":"ST.Parser.html#module-payload-types"},{"type":"module","doc":"```\n&Server:{\n  GetData(string).+Server:{\n    Data((string, number[])).end\n  }\n}\n```\n\nThis session type describes a protocol where:\n1. The user sends a `GetData` message with a string payload to the server\n2. The server responds with a `Data` message containing a tuple of a string and a number array\n3. The session then terminates","title":"Example Session Type - ST.Parser","ref":"ST.Parser.html#module-example-session-type"},{"type":"function","doc":"Parses a complete session type expression.\n\nReturns `{:ok, parsed_type}` on success or `{:error, reason}` on failure.","title":"ST.Parser.parse/1","ref":"ST.Parser.html#parse/1"},{"type":"function","doc":"- `input`: String containing the session type expression to parse","title":"Parameters - ST.Parser.parse/1","ref":"ST.Parser.html#parse/1-parameters"},{"type":"function","doc":"iex> ST.Parser.parse(\"&Server:{ Ack(unit).end }\")\n    {:ok, %ST.SIn{\n      from: :server,\n      branches: [\n        %ST.SBranch{\n          label: :ack,\n          payload: :unit,\n          continue_as: %ST.SEnd{}\n        }\n      ]\n    }}\n\n    iex> ST.Parser.parse(\"+Client:{ Request(string).end }\")\n    {:ok, %ST.SOut{\n      to: :client,\n      branches: [\n        %ST.SBranch{\n          label: :request,\n          payload: :binary,\n          continue_as: %ST.SEnd{}\n        }\n      ]\n    }}\n\n    iex> ST.Parser.parse(\"end\")\n    {:ok, %ST.SEnd{}}","title":"Examples - ST.Parser.parse/1","ref":"ST.Parser.html#parse/1-examples"},{"type":"function","doc":"Parses a session type expression, raising an exception on failure.\n\nReturns the parsed type directly on success.","title":"ST.Parser.parse!/1","ref":"ST.Parser.html#parse!/1"},{"type":"function","doc":"- `input`: String containing the session type expression to parse","title":"Parameters - ST.Parser.parse!/1","ref":"ST.Parser.html#parse!/1-parameters"},{"type":"function","doc":"iex> ST.Parser.parse!(\"end\")\n    %ST.SEnd{}\n\n    iex> ST.Parser.parse!(\"invalid\")\n    ** (RuntimeError) Parser error: ...","title":"Examples - ST.Parser.parse!/1","ref":"ST.Parser.html#parse!/1-examples"},{"type":"function","doc":"- `RuntimeError`: When parsing fails for any reason","title":"Raises - ST.Parser.parse!/1","ref":"ST.Parser.html#parse!/1-raises"},{"type":"type","doc":"Result of a failed parse operation containing an error message.","title":"ST.Parser.parse_error/0","ref":"ST.Parser.html#t:parse_error/0"},{"type":"type","doc":"Result of a parse operation, either success or failure.","title":"ST.Parser.parse_result/0","ref":"ST.Parser.html#t:parse_result/0"},{"type":"type","doc":"Result of a successful parse operation.","title":"ST.Parser.parse_success/0","ref":"ST.Parser.html#t:parse_success/0"},{"type":"function","doc":"Parses a payload type expression.\n\nReturns `{:ok, parsed_type}` on success or `{:error, reason}` on failure.","title":"ST.Parser.parse_type/1","ref":"ST.Parser.html#parse_type/1"},{"type":"function","doc":"- `input`: String containing the payload type expression to parse","title":"Parameters - ST.Parser.parse_type/1","ref":"ST.Parser.html#parse_type/1-parameters"},{"type":"function","doc":"iex> ST.Parser.parse_type(\"string\")\n    {:ok, :binary}\n\n    iex> ST.Parser.parse_type(\"boolean[]\")\n    {:ok, {:list, [:boolean]}}\n\n    iex> ST.Parser.parse_type(\"(string, number)\")\n    {:ok, {:tuple, [:binary, :number]}}","title":"Examples - ST.Parser.parse_type/1","ref":"ST.Parser.html#parse_type/1-examples"},{"type":"function","doc":"Parses a payload type expression, raising an exception on failure.\n\nReturns the parsed type directly on success.","title":"ST.Parser.parse_type!/1","ref":"ST.Parser.html#parse_type!/1"},{"type":"function","doc":"- `input`: String containing the payload type expression to parse","title":"Parameters - ST.Parser.parse_type!/1","ref":"ST.Parser.html#parse_type!/1-parameters"},{"type":"function","doc":"iex> ST.Parser.parse_type!(\"string\")\n    :binary\n\n    iex> ST.Parser.parse_type!(\"invalid_type\")\n    ** (RuntimeError) Type parser error: ...","title":"Examples - ST.Parser.parse_type!/1","ref":"ST.Parser.html#parse_type!/1-examples"},{"type":"function","doc":"- `RuntimeError`: When parsing fails for any reason","title":"Raises - ST.Parser.parse_type!/1","ref":"ST.Parser.html#parse_type!/1-raises"},{"type":"type","doc":"Result of a parse_type operation, either success or failure.","title":"ST.Parser.type_result/0","ref":"ST.Parser.html#t:type_result/0"},{"type":"type","doc":"Result of a successful parse_type operation.","title":"ST.Parser.type_success/0","ref":"ST.Parser.html#t:type_success/0"},{"type":"module","doc":"Low-level implementation of the Session Type Parser.\n\nThis module contains the NimbleParsec-based parser definitions for session types.\nMost users should use the higher-level API in the `ST.Parser` module rather\nthan directly using the functions in this module.\n\nThe parser handles:\n- Basic payload types (string, number, boolean, unit)\n- Complex payload types (lists, tuples)\n- Session type constructs (input, output, end)\n- Branch definitions with continuations","title":"ST.Parser.Core","ref":"ST.Parser.Core.html"},{"type":"function","doc":"Parses a basic type.","title":"ST.Parser.Core.parse_basic_type/2","ref":"ST.Parser.Core.html#parse_basic_type/2"},{"type":"function","doc":"- `input`: String containing the basic type expression","title":"Parameters - ST.Parser.Core.parse_basic_type/2","ref":"ST.Parser.Core.html#parse_basic_type/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_basic_type/2","ref":"ST.Parser.Core.html#parse_basic_type/2-returns"},{"type":"function","doc":"Parses a branch in a session type.","title":"ST.Parser.Core.parse_branch/2","ref":"ST.Parser.Core.html#parse_branch/2"},{"type":"function","doc":"- `input`: String containing the branch expression","title":"Parameters - ST.Parser.Core.parse_branch/2","ref":"ST.Parser.Core.html#parse_branch/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_branch/2","ref":"ST.Parser.Core.html#parse_branch/2-returns"},{"type":"function","doc":"Parses an end session type.","title":"ST.Parser.Core.parse_end/2","ref":"ST.Parser.Core.html#parse_end/2"},{"type":"function","doc":"- `input`: String containing the end expression","title":"Parameters - ST.Parser.Core.parse_end/2","ref":"ST.Parser.Core.html#parse_end/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_end/2","ref":"ST.Parser.Core.html#parse_end/2-returns"},{"type":"function","doc":"Parses an identifier.","title":"ST.Parser.Core.parse_identifier/2","ref":"ST.Parser.Core.html#parse_identifier/2"},{"type":"function","doc":"- `input`: String containing the identifier","title":"Parameters - ST.Parser.Core.parse_identifier/2","ref":"ST.Parser.Core.html#parse_identifier/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_identifier/2","ref":"ST.Parser.Core.html#parse_identifier/2-returns"},{"type":"function","doc":"Parses an input session type.","title":"ST.Parser.Core.parse_input/2","ref":"ST.Parser.Core.html#parse_input/2"},{"type":"function","doc":"- `input`: String containing the input expression","title":"Parameters - ST.Parser.Core.parse_input/2","ref":"ST.Parser.Core.html#parse_input/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_input/2","ref":"ST.Parser.Core.html#parse_input/2-returns"},{"type":"function","doc":"Parses an output session type.","title":"ST.Parser.Core.parse_output/2","ref":"ST.Parser.Core.html#parse_output/2"},{"type":"function","doc":"- `input`: String containing the output expression","title":"Parameters - ST.Parser.Core.parse_output/2","ref":"ST.Parser.Core.html#parse_output/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_output/2","ref":"ST.Parser.Core.html#parse_output/2-returns"},{"type":"function","doc":"Parses a complete session type expression.","title":"ST.Parser.Core.parse_session_type/2","ref":"ST.Parser.Core.html#parse_session_type/2"},{"type":"function","doc":"- `input`: String containing the session type expression","title":"Parameters - ST.Parser.Core.parse_session_type/2","ref":"ST.Parser.Core.html#parse_session_type/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_session_type/2","ref":"ST.Parser.Core.html#parse_session_type/2-returns"},{"type":"function","doc":"Parses a tuple type.","title":"ST.Parser.Core.parse_tuple/2","ref":"ST.Parser.Core.html#parse_tuple/2"},{"type":"function","doc":"- `input`: String containing the tuple expression","title":"Parameters - ST.Parser.Core.parse_tuple/2","ref":"ST.Parser.Core.html#parse_tuple/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.parse_tuple/2","ref":"ST.Parser.Core.html#parse_tuple/2-returns"},{"type":"function","doc":"Parses a payload type.","title":"ST.Parser.Core.payload_type/2","ref":"ST.Parser.Core.html#payload_type/2"},{"type":"function","doc":"- `input`: String containing the payload type expression","title":"Parameters - ST.Parser.Core.payload_type/2","ref":"ST.Parser.Core.html#payload_type/2-parameters"},{"type":"function","doc":"- A NimbleParsec result tuple","title":"Returns - ST.Parser.Core.payload_type/2","ref":"ST.Parser.Core.html#payload_type/2-returns"},{"type":"function","doc":"Helper function for parser post-processing to wrap branch structures.","title":"ST.Parser.Core.wrap_branch/5","ref":"ST.Parser.Core.html#wrap_branch/5"},{"type":"function","doc":"Standard NimbleParsec post-traverse callback parameters.","title":"Parameters - ST.Parser.Core.wrap_branch/5","ref":"ST.Parser.Core.html#wrap_branch/5-parameters"},{"type":"function","doc":"A tuple containing the rest of the input, a list with the\nbranch structure, and the context.","title":"Returns - ST.Parser.Core.wrap_branch/5","ref":"ST.Parser.Core.html#wrap_branch/5-returns"},{"type":"function","doc":"Helper function for parser post-processing to wrap input structures.","title":"ST.Parser.Core.wrap_input/5","ref":"ST.Parser.Core.html#wrap_input/5"},{"type":"function","doc":"Standard NimbleParsec post-traverse callback parameters.","title":"Parameters - ST.Parser.Core.wrap_input/5","ref":"ST.Parser.Core.html#wrap_input/5-parameters"},{"type":"function","doc":"A tuple containing the rest of the input, a list with the\ninput structure, and the context.","title":"Returns - ST.Parser.Core.wrap_input/5","ref":"ST.Parser.Core.html#wrap_input/5-returns"},{"type":"function","doc":"Helper function to wrap a type as a list type.","title":"ST.Parser.Core.wrap_list_type/1","ref":"ST.Parser.Core.html#wrap_list_type/1"},{"type":"function","doc":"- `type`: The element type of the list","title":"Parameters - ST.Parser.Core.wrap_list_type/1","ref":"ST.Parser.Core.html#wrap_list_type/1-parameters"},{"type":"function","doc":"- A tuple of the form `{:list, [type]}`","title":"Returns - ST.Parser.Core.wrap_list_type/1","ref":"ST.Parser.Core.html#wrap_list_type/1-returns"},{"type":"function","doc":"Helper function for parser post-processing to wrap output structures.","title":"ST.Parser.Core.wrap_output/5","ref":"ST.Parser.Core.html#wrap_output/5"},{"type":"function","doc":"Standard NimbleParsec post-traverse callback parameters.","title":"Parameters - ST.Parser.Core.wrap_output/5","ref":"ST.Parser.Core.html#wrap_output/5-parameters"},{"type":"function","doc":"A tuple containing the rest of the input, a list with the\noutput structure, and the context.","title":"Returns - ST.Parser.Core.wrap_output/5","ref":"ST.Parser.Core.html#wrap_output/5-returns"},{"type":"function","doc":"Helper function for parser post-processing to wrap tuple types.","title":"ST.Parser.Core.wrap_tuple_type/5","ref":"ST.Parser.Core.html#wrap_tuple_type/5"},{"type":"function","doc":"Standard NimbleParsec post-traverse callback parameters.","title":"Parameters - ST.Parser.Core.wrap_tuple_type/5","ref":"ST.Parser.Core.html#wrap_tuple_type/5-parameters"},{"type":"function","doc":"A tuple containing the rest of the input, a list with the\ntuple type, and the context.","title":"Returns - ST.Parser.Core.wrap_tuple_type/5","ref":"ST.Parser.Core.html#wrap_tuple_type/5-returns"},{"type":"module","doc":"Represents a single branch in a choice or a single action sequence.\n\nEach branch has a label, a payload type, and a continuation session type.","title":"ST.SBranch","ref":"ST.SBranch.html"},{"type":"type","doc":"A branch containing:\n- label: The message label as a snake_case atom\n- payload: The payload type of the message\n- continue_as: The continuation session type after this branch","title":"ST.SBranch.t/0","ref":"ST.SBranch.html#t:t/0"},{"type":"module","doc":"Represents the termination of a session path.\n\nThis indicates that the communication on this particular path has ended.","title":"ST.SEnd","ref":"ST.SEnd.html"},{"type":"type","doc":"An end session type marker (empty struct)","title":"ST.SEnd.t/0","ref":"ST.SEnd.html#t:t/0"},{"type":"module","doc":"Represents receiving messages (external choice).\n\nThis session type indicates that the current role is expecting to\nreceive one of several possible messages from another role.","title":"ST.SIn","ref":"ST.SIn.html"},{"type":"type","doc":"An input session type containing:\n- from: The role sending the message(s) as a snake_case atom\n- branches: List of possible message branches that can be received","title":"ST.SIn.t/0","ref":"ST.SIn.html#t:t/0"},{"type":"module","doc":"Represents sending messages (internal choice).\n\nThis session type indicates that the current role will send\none of several possible messages to another role.","title":"ST.SOut","ref":"ST.SOut.html"},{"type":"type","doc":"An output session type containing:\n- to: The role receiving the message(s) as a snake_case atom\n- branches: List of possible message branches that can be sent","title":"ST.SOut.t/0","ref":"ST.SOut.html#t:t/0"},{"type":"extras","doc":"# ST Parser\n\nA simple, lightweight, flexible parser for Session Types in Elixir.\n\nST Parser converts textual session type descriptions into typed Elixir data structures, enabling formal verification and implementation of communication protocols between distributed system components.","title":"ST Parser","ref":"readme.html"},{"type":"extras","doc":"Session types provide a way to formally describe communication protocols between different roles in a distributed system. They let you specify:\n\n- Who sends messages to whom\n- What data is exchanged in those messages\n- The order of interactions\n- Choices and branches in the protocol flow","title":"What are Session Types? - ST Parser","ref":"readme.html#what-are-session-types"},{"type":"extras","doc":"- Parse session type expressions into structured Elixir terms\n- Build session types programmatically with constructor functions\n- Handle complex session type constructs like input (external choice) and output (internal choice)\n- Support nested payload types (lists, tuples)\n- Clean and simple API for integration into larger projects","title":"Features - ST Parser","ref":"readme.html#features"},{"type":"extras","doc":"Add `st_parser` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:st_parser, \"~> 0.3.0\"}\n  ]\nend\n```","title":"Installation - ST Parser","ref":"readme.html#installation"},{"type":"extras","doc":"","title":"Usage - ST Parser","ref":"readme.html#usage"},{"type":"extras","doc":"```elixir\n# Parse a session type string into a structured type\n{:ok, session_type} = ST.Parser.parse(\"&Server:{ Ack(unit).end }\")\n\n# Or use the bang version which raises on error\nsession_type = ST.Parser.parse!(\"&Server:{ Ack(unit).end }\")\n\n# Parse just a payload type\n{:ok, payload_type} = ST.Parser.parse_type(\"(string, boolean[])\")\n```","title":"Parsing Session Type Expressions - ST Parser","ref":"readme.html#parsing-session-type-expressions"},{"type":"extras","doc":"```elixir\n# Create an End type\nend_type = ST.end_session()\n\n# Create a simple branch\nack_branch = ST.branch(:ack, :unit, end_type)\n\n# Create an input type (receiving a message)\ninput_type = ST.input(:server, [ack_branch])\n# Or more concisely:\ninput_type = ST.input_one(:server, :ack, :unit, end_type)\n\n# Create an output type (sending a message)\noutput_type = ST.output_one(:client, :request, :binary, end_type)\n```","title":"Building Session Types Programmatically - ST Parser","ref":"readme.html#building-session-types-programmatically"},{"type":"extras","doc":"Session type expressions use a concise syntax:\n\n```\n# Input (receiving messages)\n&Role:{ Label1(PayloadType).Continuation, Label2(PayloadType).Continuation }\n\n# Output (sending messages)\n+Role:{ Label1(PayloadType).Continuation, Label2(PayloadType).Continuation }\n\n# Termination\nend\n```\n\nPayload types can be:\n\n- Basic types: `string`, `number`, `boolean`, `unit`\n- List types: `type[]` (e.g., `string[]`)\n- Tuple types: `(type1, type2, ...)` (e.g., `(string, number[])`)","title":"Session Type Syntax - ST Parser","ref":"readme.html#session-type-syntax"},{"type":"extras","doc":"```elixir\nrequest_response = \"\"\"\n&Server:{\n  Request(string).+Client:{\n    Response((string, number[])).end,\n    Error(string).end\n  }\n}\n\"\"\"\n\n{:ok, protocol} = ST.Parser.parse(request_response)\n```\n\nThis describes a protocol where:\n1. The user sends a `Request` with a string payload to the server\n2. The client responds with either:\n   - A `Response` containing a tuple of a string and a number array, then ends\n   - An `Error` with a string message, then ends","title":"Example: A Simple Request-Response Protocol - ST Parser","ref":"readme.html#example-a-simple-request-response-protocol"},{"type":"extras","doc":"Full documentation is available via ExDoc:\n\n```\nmix docs\n```","title":"Documentation - ST Parser","ref":"readme.html#documentation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}